App

Struct App 

pub struct App {
Show 59 fields pub language: Language, pub should_quit: bool, pub repo_info: Option<RepoInfo>, pub selected_index: usize, pub show_detail: bool, pub input_mode: InputMode, pub filter_text: String, pub filter_query: FilterQuery, pub branches: Vec<BranchInfo>, pub branch_selected_index: usize, pub branch_create_input: String, pub file_statuses: Vec<FileStatus>, pub status_selected_index: usize, pub commit_message: String, pub commit_type: Option<CommitType>, pub status_message: Option<String>, pub status_message_level: StatusMessageLevel, pub status_message_at: Option<Instant>, pub is_loading: bool, pub show_help: bool, pub topology_cache: Option<BranchTopology>, pub topology_nav: ListNavigation, pub branch_recommendations_cache: Option<BranchRecommendations>, pub commit_suggestions: Vec<CommitSuggestion>, pub suggestion_selected_index: usize, pub detail_nav: ListNavigation, pub detail_diff_cache: Option<CommitDiff>, pub stats_view: StatsViewState, pub heatmap_view: HeatmapViewState, pub file_history_view: FileHistoryViewState, pub timeline_cache: Option<ActivityTimeline>, pub blame_view: BlameViewState, pub ownership_view: OwnershipViewState, pub stash_view: StashViewState, pub patch_view: PatchViewState, pub branch_compare_view: BranchCompareViewState, pub related_files_view: RelatedFilesViewState, pub impact_score_view: ImpactScoreViewState, pub change_coupling_view: ChangeCouplingViewState, pub quality_score_view: QualityScoreViewState, pub health_view: HealthViewState, pub file_diff: FileDiffState, pub commit_detail: CommitDetailState, pub filter_presets: FilterPresets, pub preset_save_slot: usize, pub preset_save_name: String, pub relevance_mode: bool, pub working_files: Vec<String>, pub quick_action_selected_index: usize, pub active_sidebar_panel: SidebarPanel, pub sidebar_focused: bool, pub sidebar_width_ratio: u16, pub watch_mode: bool, pub session_cache: Option<Vec<AiSession>>, pub staged_risk_score: Option<f64>, pub staged_risk_level: Option<RiskLevel>, pub staging_groups: Vec<StagingGroup>, pub review_queue_view: ReviewQueueViewState, pub pr_create_state: PrCreateState, /* private fields */
}
Application state

Fields

language: Language

Display language

should_quit: bool

Whether the application should quit

repo_info: Option<RepoInfo>

Repository information

selected_index: usize

Currently selected event index (within filtered_indices)

show_detail: bool

Detail display mode

input_mode: InputMode

Input mode

filter_text: String

Filter string

filter_query: FilterQuery

Parsed filter query

branches: Vec<BranchInfo>

Branch list

branch_selected_index: usize

Branch selection index

branch_create_input: String

Input string for branch creation

file_statuses: Vec<FileStatus>

File status list

status_selected_index: usize

Status selection index

commit_message: String

Commit message

commit_type: Option<CommitType>

Selected commit type

status_message: Option<String>

Status message (for displaying operation results)

status_message_level: StatusMessageLevel

Status message level

status_message_at: Option<Instant>

Timestamp when status message was set (for auto-clearing)

is_loading: bool

Background loading flag

show_help: bool

Help display flag

topology_cache: Option<BranchTopology>

Topology cache

topology_nav: ListNavigation

Topology view navigation state

branch_recommendations_cache: Option<BranchRecommendations>

Branch recommendation cache

commit_suggestions: Vec<CommitSuggestion>

Commit suggestion list

suggestion_selected_index: usize

Suggestion selection index

detail_nav: ListNavigation

Detail view navigation state

detail_diff_cache: Option<CommitDiff>

Detail view diff cache

stats_view: StatsViewState

Stats view state

heatmap_view: HeatmapViewState

Heatmap view state

file_history_view: FileHistoryViewState

File history view state

timeline_cache: Option<ActivityTimeline>

Activity timeline cache

blame_view: BlameViewState

Blame view state

ownership_view: OwnershipViewState

Code ownership view state

stash_view: StashViewState

Stash view state

patch_view: PatchViewState

Patch view state

branch_compare_view: BranchCompareViewState

Branch compare view state

related_files_view: RelatedFilesViewState

Related files view state

impact_score_view: ImpactScoreViewState

Impact Score view state

change_coupling_view: ChangeCouplingViewState

Change Coupling view state

quality_score_view: QualityScoreViewState

Quality Score view state

health_view: HealthViewState

Health dashboard view state

file_diff: FileDiffState

File diff cache state

commit_detail: CommitDetailState

Commit detail panel state

filter_presets: FilterPresets

Filter presets

preset_save_slot: usize

Preset save dialog: selected slot (1-5)

preset_save_name: String

Preset save dialog: preset name input

relevance_mode: bool

Whether relevance mode is enabled

working_files: Vec<String>

Changed files in the working tree

quick_action_selected_index: usize

Currently selected index in quick actions

active_sidebar_panel: SidebarPanel

Dashboard-style: active sidebar panel

sidebar_focused: bool

Dashboard-style: whether sidebar has focus (false means main panel)

sidebar_width_ratio: u16

Dashboard-style: sidebar width ratio (percent, default 33)

watch_mode: bool

Watch mode (auto-refresh on file changes)

session_cache: Option<Vec<AiSession>>

AI session cache

staged_risk_score: Option<f64>

Staged risk score (0.0-1.0)

staged_risk_level: Option<RiskLevel>

Staged risk level

staging_groups: Vec<StagingGroup>

Smart staging groups

review_queue_view: ReviewQueueViewState

Review queue view state

pr_create_state: PrCreateState

PR create state

Implementations

Source

impl App

pub fn start_topology_view(&mut self, topology: BranchTopology)

Start topology view

pub fn end_topology_view(&mut self)

End topology view

pub fn selected_branch_recommendation(&self) -> Option<&BranchRecommendation>

Get recommended action for the selected branch

pub fn topology_move_up(&mut self)

Move topology selection up

pub fn topology_move_down(&mut self)

Move topology selection down

pub fn topology_adjust_scroll(&mut self, visible_lines: usize)

Set visible line count for topology view and adjust scroll

pub fn selected_topology_branch(&self) -> Option<&str>

Get selected topology branch name

pub fn generate_commit_suggestions(&mut self)

Generate commit suggestions

pub fn apply_suggestion(&mut self, index: usize)

Apply suggestion

pub fn suggestion_move_up(&mut self)

Move suggestion selection up

pub fn suggestion_move_down(&mut self)

Move suggestion selection down

pub fn start_stats_view(&mut self, stats: RepoStats)

Start stats view

pub fn end_stats_view(&mut self)

End stats view

pub fn export_stats(&mut self) -> Option<String>

Export statistics

pub fn stats_move_up(&mut self)

Move selection up in stats view

pub fn stats_move_down(&mut self)

Move selection down in stats view

pub fn stats_adjust_scroll(&mut self, visible_lines: usize)

Adjust stats view scroll

pub fn selected_author(&self) -> Option<&str>

Get selected author name

pub fn filter_by_author(&mut self, author: &str)

Apply filter by author

pub fn start_heatmap_view(&mut self, heatmap: FileHeatmap)

Start heatmap view

pub fn end_heatmap_view(&mut self)

End heatmap view

pub fn export_heatmap(&mut self) -> Option<String>

Export heatmap

pub fn heatmap_increase_aggregation(&mut self)

Switch heatmap aggregation level to next (+ key)

pub fn heatmap_decrease_aggregation(&mut self)

Switch heatmap aggregation level to previous (- key)

pub fn heatmap_move_up(&mut self)

Move selection up in heatmap view

pub fn heatmap_move_down(&mut self)

Move selection down in heatmap view

pub fn heatmap_adjust_scroll(&mut self, visible_lines: usize)

Adjust heatmap view scroll

pub fn selected_heatmap_file(&self) -> Option<&str>

Get selected file path

pub fn filter_by_file(&mut self, file_path: &str)

Apply filter by file

pub fn start_file_history_view( &mut self, path: String, history: Vec<FileHistoryEntry>, )

Start file history view

pub fn end_file_history_view(&mut self)

End file history view

pub fn file_history_move_up(&mut self)

Move selection up in file history view

pub fn file_history_move_down(&mut self)

Move selection down in file history view

pub fn file_history_adjust_scroll(&mut self, visible_lines: usize)

Adjust file history view scroll

pub fn selected_file_history(&self) -> Option<&FileHistoryEntry>

Get selected file history entry

pub fn start_timeline_view(&mut self, timeline: ActivityTimeline)

Start timeline view

pub fn end_timeline_view(&mut self)

End timeline view

pub fn export_timeline(&mut self) -> Option<String>

Export timeline

pub fn start_blame_view(&mut self, path: String, blame: Vec<BlameLine>)

Start blame view

pub fn end_blame_view(&mut self)

End blame view

pub fn blame_move_up(&mut self)

Move selection up in blame view

pub fn blame_move_down(&mut self)

Move selection down in blame view

pub fn blame_adjust_scroll(&mut self, visible_lines: usize)

Adjust blame view scroll

pub fn selected_blame_line(&self) -> Option<&BlameLine>

Get selected blame line

pub fn start_ownership_view(&mut self, ownership: CodeOwnership)

Start code ownership view

pub fn end_ownership_view(&mut self)

End code ownership view

pub fn export_ownership(&mut self) -> Option<String>

Export code ownership

pub fn ownership_move_up(&mut self)

Move selection up in code ownership view

pub fn ownership_move_down(&mut self)

Move selection down in code ownership view

pub fn ownership_adjust_scroll(&mut self, visible_lines: usize)

Adjust code ownership view scroll

pub fn selected_ownership_entry(&self) -> Option<&CodeOwnershipEntry>

Get selected ownership entry

pub fn start_stash_view(&mut self, stashes: Vec<StashEntry>)

Start stash view

pub fn end_stash_view(&mut self)

End stash view

pub fn stash_move_up(&mut self)

Move selection up in stash view

pub fn stash_move_down(&mut self)

Move selection down in stash view

pub fn stash_adjust_scroll(&mut self, visible_lines: usize)

Adjust stash view scroll

pub fn selected_stash_entry(&self) -> Option<&StashEntry>

Get selected stash entry

pub fn update_stash_cache(&mut self, stashes: Vec<StashEntry>)

Update stash list

pub fn start_patch_view(&mut self, patch: FilePatch)

Start patch view

pub fn end_patch_view(&mut self)

End patch view

pub fn patch_scroll_up(&mut self)

Scroll up in patch view

pub fn patch_scroll_down(&mut self, visible_lines: usize)

Scroll down in patch view

pub fn apply_preset(&mut self, slot: usize)

Apply filter preset (1-5 keys)

pub fn start_preset_save(&mut self)

Start preset save dialog (Ctrl+S)

pub fn end_preset_save(&mut self)

End preset save dialog

pub fn preset_slot_up(&mut self)

Preset save: move slot selection up

pub fn preset_slot_down(&mut self)

Preset save: move slot selection down

pub fn preset_name_push(&mut self, c: char)

Preset save: add character to name input

pub fn preset_name_pop(&mut self)

Preset save: remove character from name input

pub fn save_preset(&mut self) -> bool

Save preset

pub fn delete_preset(&mut self, slot: usize)

Delete preset

pub fn start_branch_compare_view(&mut self, compare: BranchCompare)

Start branch compare view

pub fn end_branch_compare_view(&mut self)

End branch compare view

pub fn branch_compare_toggle_tab(&mut self)

Toggle tab

pub fn branch_compare_move_up(&mut self)

Move selection up

pub fn branch_compare_move_down(&mut self)

Move selection down

pub fn branch_compare_adjust_scroll(&mut self, visible_lines: usize)

Adjust scroll

pub fn selected_branch_compare_commit(&self) -> Option<&CompareCommit>

Get currently selected commit

pub fn toggle_relevance_mode(&mut self)

Toggle relevance mode

pub fn set_working_files(&mut self, files: Vec<String>)

Set working files

pub fn apply_relevance_sort(&mut self)

Calculate relevance scores and apply sorting

pub fn get_relevance_score(&self, hash: &str) -> Option<f32>

Get relevance score for the specified hash

pub fn is_relevance_mode(&self) -> bool

Whether relevance mode is active

Start related files view

End related files view

pub fn related_files_move_down(&mut self)

Move down in related files view

pub fn related_files_move_up(&mut self)

Move up in related files view

pub fn related_files_adjust_scroll(&mut self, visible_lines: usize)

Adjust related files view scroll

pub fn start_impact_score_view(&mut self, analysis: CommitImpactAnalysis)

Start Impact Score view

pub fn end_impact_score_view(&mut self)

End Impact Score view

pub fn impact_score_move_up(&mut self)

Move selection up in Impact Score view

pub fn impact_score_move_down(&mut self)

Move selection down in Impact Score view

pub fn impact_score_adjust_scroll(&mut self, visible_lines: usize)

Adjust Impact Score view scroll

pub fn selected_impact_score(&self) -> Option<&CommitImpactScore>

Get selected Impact Score entry

pub fn export_impact_scores(&mut self) -> Option<String>

Export Impact Score

pub fn start_change_coupling_view(&mut self, analysis: ChangeCouplingAnalysis)

Start Change Coupling view

pub fn end_change_coupling_view(&mut self)

End Change Coupling view

pub fn change_coupling_move_up(&mut self)

Move selection up in Change Coupling view

pub fn change_coupling_move_down(&mut self)

Move selection down in Change Coupling view

pub fn change_coupling_adjust_scroll(&mut self, visible_lines: usize)

Adjust Change Coupling view scroll

pub fn selected_change_coupling(&self) -> Option<&FileCoupling>

Get selected Change Coupling entry

pub fn export_change_coupling(&mut self) -> Option<String>

Export Change Coupling

pub fn start_quality_score_view(&mut self, analysis: CommitQualityAnalysis)

Start Quality Score view

pub fn end_quality_score_view(&mut self)

End Quality Score view

pub fn quality_score_move_up(&mut self)

Move selection up in Quality Score view

pub fn quality_score_move_down(&mut self)

Move selection down in Quality Score view

pub fn quality_score_adjust_scroll(&mut self, visible_lines: usize)

Adjust Quality Score view scroll

pub fn selected_quality_score(&self) -> Option<&CommitQualityScore>

Get selected Quality Score entry

pub fn export_quality_scores(&mut self) -> Option<String>

Export Quality Score

pub fn commit_detail_file_move_up(&mut self)

Move file selection up in commit detail panel

pub fn commit_detail_file_move_down(&mut self)

Move file selection down in commit detail panel

pub fn commit_detail_toggle_file_diff(&mut self)

Toggle diff expand/collapse for the selected file in commit detail panel

pub fn commit_detail_expand_all(&mut self)

Expand diff for all files in commit detail panel

pub fn commit_detail_collapse_all(&mut self)

Collapse diff for all files in commit detail panel

pub fn reset_commit_detail_file_state(&mut self)

Commit detail: reset file selection, expand state, and scroll

pub fn commit_detail_auto_scroll(&mut self, visible_height: usize)

Commit detail: auto-adjust scroll to keep selected file visible

pub fn start_review_queue_view(&mut self)

Start review queue view

pub fn end_review_queue_view(&mut self)

End review queue view

pub fn review_queue_move_up(&mut self)

Move review queue selection up

pub fn review_queue_move_down(&mut self)

Move review queue selection down

pub fn start_pr_create(&mut self)

Start PR create view

pub fn end_pr_create(&mut self)

End PR create view

Source

impl App

pub fn new() -> Self

pub fn load(&mut self, repo_info: RepoInfo, events: Vec<GitEvent>)

Set repository information and events

pub fn set_repo(&mut self, repo: Repository)

Set repository for caching

pub fn get_repo(&self) -> Option<&Repository>

Get reference to cached repository

pub fn set_head_hash(&mut self, hash: String)

Set HEAD hash (for @ key jump)

pub fn head_hash(&self) -> Option<&str>

Get HEAD hash

pub fn events(&self) -> impl Iterator<Item = &GitEvent>

Get filtered event list as an iterator

pub fn event_at(&self, index: usize) -> Option<&GitEvent>

Get filtered event by index

pub fn all_events(&self) -> &[GitEvent]

Get reference to all events

pub fn event_count(&self) -> usize

Get count of filtered events

pub fn quit(&mut self)

Quit with q key

pub fn move_up(&mut self)

Move selection up

pub fn move_down(&mut self)

Move selection down

pub fn move_to_top(&mut self)

Move to top (gg)

pub fn jump_to_head(&mut self)

Jump to HEAD (@ key) Moves to HEAD position even during filtering

pub fn move_to_bottom(&mut self)

Move to bottom (G)

pub fn page_down(&mut self, page_size: usize)

Page down (Ctrl+d)

pub fn page_up(&mut self, page_size: usize)

Page up (Ctrl+u)

pub fn toggle_help(&mut self)

Toggle help display

pub fn close_help(&mut self)

Close help

pub fn start_quick_action_view(&mut self)

pub fn end_quick_action_view(&mut self)

pub fn quick_action_move_down(&mut self)

pub fn quick_action_move_up(&mut self)

pub fn selected_quick_action(&self) -> Option<QuickAction>

pub fn jump_to_next_label(&mut self)

Jump to next labeled commit (] key)

pub fn jump_to_prev_label(&mut self)

Jump to previous labeled commit ([ key)

pub fn selected_event(&self) -> Option<&GitEvent>

Get currently selected event

pub fn open_detail(&mut self)

Open detail view

pub fn close_detail(&mut self)

Close detail view

pub fn set_detail_diff(&mut self, diff: CommitDiff)

Cache diff in detail view

pub fn set_file_diff(&mut self, patch: FilePatch, path: String)

Set file diff cache

pub fn clear_file_diff(&mut self)

Clear file diff cache

pub fn file_diff_cache_path(&self) -> Option<&str>

Get file diff cache path

pub fn detail_move_up(&mut self)

Move file selection up in detail view

pub fn detail_move_down(&mut self)

Move file selection down in detail view

pub fn detail_adjust_scroll(&mut self, visible_lines: usize)

Adjust detail view scroll (considering visible line count)

pub fn start_filter(&mut self)

Start filter mode

pub fn end_filter(&mut self)

End filter mode

pub fn filter_push(&mut self, c: char)

Add filter character

pub fn filter_pop(&mut self)

Remove filter character

pub fn filter_clear(&mut self)

Clear filter

pub fn preload_file_cache( &mut self, get_files: impl Fn(&str) -> Option<Vec<String>>, )

Preload file cache (when file filter is active) Note: Only caches the latest N entries to prevent UI blocking

pub fn clear_file_cache(&mut self)

Clear file cache

pub fn file_cache_is_empty(&self) -> bool

Whether file cache is empty

pub fn reapply_filter(&mut self)

Reapply filter (used after cache update)

pub fn repo_name(&self) -> &str

Get repository name

pub fn branch_name(&self) -> &str

Get branch name

pub fn start_branch_select(&mut self, branches: Vec<BranchInfo>)

Start branch selection mode

pub fn end_branch_select(&mut self)

End branch selection mode

pub fn branch_move_up(&mut self)

Move branch selection up

pub fn branch_move_down(&mut self)

Move branch selection down

pub fn selected_branch(&self) -> Option<&str>

Get selected branch name

pub fn update_branch(&mut self, branch: String)

Update repository info after branch switch

pub fn start_branch_create(&mut self)

Start branch creation mode

pub fn end_branch_create(&mut self)

End branch creation mode

pub fn branch_create_push(&mut self, c: char)

Add character to branch name input

pub fn branch_create_pop(&mut self)

Remove character from branch name input

pub fn branch_create_name(&self) -> &str

Get branch name being entered

pub fn all_events_replace(&mut self, events: Vec<GitEvent>)

Replace event list

pub fn annotate_events<F: FnMut(&mut GitEvent)>(&mut self, f: F)

Annotate all events with a mutation closure

pub fn filtered_indices_reset(&mut self, count: usize)

Reset filter indices

pub fn start_status_view(&mut self, statuses: Vec<FileStatus>)

Start status view mode

pub fn end_status_view(&mut self)

End status view mode

pub fn status_move_up(&mut self)

Move status selection up

pub fn status_move_down(&mut self)

Move status selection down

pub fn selected_file_status(&self) -> Option<&FileStatus>

Get selected file status

pub fn update_branches(&mut self, branches: Vec<BranchInfo>)

Update branch list

pub fn update_file_statuses(&mut self, statuses: Vec<FileStatus>)

Update file status list

pub fn set_status_message(&mut self, msg: String)

Set status message

pub fn clear_expired_status_message(&mut self)

Clear expired status messages (auto-clear after 5 seconds)

pub fn start_commit_input(&mut self)

Start commit input mode

pub fn end_commit_input(&mut self)

End commit input mode

pub fn select_commit_type(&mut self, commit_type: CommitType)

Select commit type

pub fn commit_message_push(&mut self, c: char)

Add character to commit message

pub fn commit_message_pop(&mut self)

Remove character from commit message

pub fn commit_message_clear(&mut self)

Clear commit message

pub fn start_loading(&mut self)

Start loading state

pub fn finish_loading(&mut self)

End loading state

pub fn append_events(&mut self, events: Vec<GitEvent>)

Append events (for background loading)

pub fn filter_description(&self) -> String

Get filter query description